aboutsummaryrefslogtreecommitdiff
path: root/CST116-BlankConsole
diff options
context:
space:
mode:
author[email protected] <[email protected]>2022-09-29 15:15:21 -0700
committer[email protected] <[email protected]>2022-09-29 15:15:21 -0700
commit9f980d3682b9d88bcf5de990d2ac34266ba232c5 (patch)
treeabf3ab98b325b46dc4adcccd416aa39adb7fb821 /CST116-BlankConsole
parentI am commit (diff)
downloadcst116-lab0-smith-main.tar.xz
cst116-lab0-smith-main.zip
Done. Finished, evenHEADmain
Diffstat (limited to 'CST116-BlankConsole')
-rw-r--r--CST116-BlankConsole/CST116-BlankConsole.vcxproj2
-rw-r--r--CST116-BlankConsole/CST116-BlankConsole.vcxproj.filters2
-rw-r--r--CST116-BlankConsole/CST116-Lab0-Smith-pseudo.txt2
-rw-r--r--CST116-BlankConsole/CST116-Lab0-Smith.cpp (renamed from CST116-BlankConsole/CST116-BlankConsole.cpp)47
-rw-r--r--CST116-BlankConsole/CST116-Lab0-Smith.txt2
-rw-r--r--CST116-BlankConsole/checklist.txt5
-rw-r--r--CST116-BlankConsole/x64/Debug/CST116-B.369d37de.tlog/CL.command.1.tlogbin0 -> 910 bytes
-rw-r--r--CST116-BlankConsole/x64/Debug/CST116-B.369d37de.tlog/CL.read.1.tlogbin0 -> 19762 bytes
-rw-r--r--CST116-BlankConsole/x64/Debug/CST116-B.369d37de.tlog/CL.write.1.tlogbin0 -> 800 bytes
-rw-r--r--CST116-BlankConsole/x64/Debug/CST116-B.369d37de.tlog/CST116-BlankConsole.lastbuildstate2
-rw-r--r--CST116-BlankConsole/x64/Debug/CST116-B.369d37de.tlog/link.command.1.tlogbin0 -> 1692 bytes
-rw-r--r--CST116-BlankConsole/x64/Debug/CST116-B.369d37de.tlog/link.read.1.tlogbin0 -> 3814 bytes
-rw-r--r--CST116-BlankConsole/x64/Debug/CST116-B.369d37de.tlog/link.write.1.tlogbin0 -> 880 bytes
-rw-r--r--CST116-BlankConsole/x64/Debug/CST116-BlankConsole.exebin0 -> 68096 bytes
-rw-r--r--CST116-BlankConsole/x64/Debug/CST116-BlankConsole.exe.recipe11
-rw-r--r--CST116-BlankConsole/x64/Debug/CST116-BlankConsole.ilkbin0 -> 668280 bytes
-rw-r--r--CST116-BlankConsole/x64/Debug/CST116-BlankConsole.log2
-rw-r--r--CST116-BlankConsole/x64/Debug/CST116-BlankConsole.pdbbin0 -> 1249280 bytes
-rw-r--r--CST116-BlankConsole/x64/Debug/CST116-BlankConsole.vcxproj.FileListAbsolute.txt1
-rw-r--r--CST116-BlankConsole/x64/Debug/CST116-Lab0-Smith.objbin0 -> 73739 bytes
-rw-r--r--CST116-BlankConsole/x64/Debug/vc143.idbbin0 -> 158720 bytes
-rw-r--r--CST116-BlankConsole/x64/Debug/vc143.pdbbin0 -> 397312 bytes
22 files changed, 54 insertions, 22 deletions
diff --git a/CST116-BlankConsole/CST116-BlankConsole.vcxproj b/CST116-BlankConsole/CST116-BlankConsole.vcxproj
index a0056fb..d074f7f 100644
--- a/CST116-BlankConsole/CST116-BlankConsole.vcxproj
+++ b/CST116-BlankConsole/CST116-BlankConsole.vcxproj
@@ -127,7 +127,7 @@
</Link>
</ItemDefinitionGroup>
<ItemGroup>
- <ClCompile Include="CST116-BlankConsole.cpp" />
+ <ClCompile Include="CST116-Lab0-Smith.cpp" />
</ItemGroup>
<Import Project="$(VCTargetsPath)\Microsoft.Cpp.targets" />
<ImportGroup Label="ExtensionTargets">
diff --git a/CST116-BlankConsole/CST116-BlankConsole.vcxproj.filters b/CST116-BlankConsole/CST116-BlankConsole.vcxproj.filters
index 08906aa..b464389 100644
--- a/CST116-BlankConsole/CST116-BlankConsole.vcxproj.filters
+++ b/CST116-BlankConsole/CST116-BlankConsole.vcxproj.filters
@@ -15,7 +15,7 @@
</Filter>
</ItemGroup>
<ItemGroup>
- <ClCompile Include="CST116-BlankConsole.cpp">
+ <ClCompile Include="CST116-Lab0-Smith.cpp">
<Filter>Source Files</Filter>
</ClCompile>
</ItemGroup>
diff --git a/CST116-BlankConsole/CST116-Lab0-Smith-pseudo.txt b/CST116-BlankConsole/CST116-Lab0-Smith-pseudo.txt
new file mode 100644
index 0000000..5af8f8f
--- /dev/null
+++ b/CST116-BlankConsole/CST116-Lab0-Smith-pseudo.txt
@@ -0,0 +1,2 @@
+1. write to the screen "Hello World!" then move down a line
+2. write to the screen ""My name is Benjamin Smith. My Github it Smith-Benjamin" then move down a line \ No newline at end of file
diff --git a/CST116-BlankConsole/CST116-Lab0-Smith.txt b/CST116-BlankConsole/CST116-Lab0-Smith.txt
new file mode 100644
index 0000000..7e737e8
--- /dev/null
+++ b/CST116-BlankConsole/CST116-Lab0-Smith.txt
@@ -0,0 +1,2 @@
+Hello World!
+My name is Benjamin Smith. My Github it Smith-Benjamin \ No newline at end of file
diff --git a/CST116-BlankConsole/checklist.txt b/CST116-BlankConsole/checklist.txt
new file mode 100644
index 0000000..45b506a
--- /dev/null
+++ b/CST116-BlankConsole/checklist.txt
@@ -0,0 +1,5 @@
+1. Go to the Git Changes tab
+2. Write out a message describing the state of the pushed contents
+3. Select Commit All
+4. Go to the menu that shows committed items
+5. Select Push \ No newline at end of file
diff --git a/CST116-BlankConsole/x64/Debug/CST116-B.369d37de.tlog/CL.command.1.tlog b/CST116-BlankConsole/x64/Debug/CST116-B.369d37de.tlog/CL.command.1.tlog
new file mode 100644
index 0000000..79892ce
--- /dev/null
+++ b/CST116-BlankConsole/x64/Debug/CST116-B.369d37de.tlog/CL.command.1.tlog
Binary files differ
diff --git a/CST116-BlankConsole/x64/Debug/CST116-B.369d37de.tlog/CL.read.1.tlog b/CST116-BlankConsole/x64/Debug/CST116-B.369d37de.tlog/CL.read.1.tlog
new file mode 100644
index 0000000..7ed0162
--- /dev/null
+++ b/CST116-BlankConsole/x64/Debug/CST116-B.369d37de.tlog/CL.read.1.tlog
Binary files differ
diff --git a/CST116-BlankConsole/x64/Debug/CST116-B.369d37de.tlog/CL.write.1.tlog b/CST116-BlankConsole/x64/Debug/CST116-B.369d37de.tlog/CL.write.1.tlog
new file mode 100644
index 0000000..09d1717
--- /dev/null
+++ b/CST116-BlankConsole/x64/Debug/CST116-B.369d37de.tlog/CL.write.1.tlog
Binary files differ
diff --git a/CST116-BlankConsole/x64/Debug/CST116-B.369d37de.tlog/CST116-BlankConsole.lastbuildstate b/CST116-BlankConsole/x64/Debug/CST116-B.369d37de.tlog/CST116-BlankConsole.lastbuildstate
new file mode 100644
index 0000000..e66ca0b
--- /dev/null
+++ b/CST116-BlankConsole/x64/Debug/CST116-B.369d37de.tlog/CST116-BlankConsole.lastbuildstate
@@ -0,0 +1,2 @@
+PlatformToolSet=v143:VCToolArchitecture=Native64Bit:VCToolsVersion=14.33.31629:TargetPlatformVersion=10.0.19041.0:
+Debug|x64|C:\Users\cowpi\Source\Repos\cst116-lab0-Smith-Benjamin\CST116-BlankConsole\|
diff --git a/CST116-BlankConsole/x64/Debug/CST116-B.369d37de.tlog/link.command.1.tlog b/CST116-BlankConsole/x64/Debug/CST116-B.369d37de.tlog/link.command.1.tlog
new file mode 100644
index 0000000..d1ac3e8
--- /dev/null
+++ b/CST116-BlankConsole/x64/Debug/CST116-B.369d37de.tlog/link.command.1.tlog
Binary files differ
diff --git a/CST116-BlankConsole/x64/Debug/CST116-B.369d37de.tlog/link.read.1.tlog b/CST116-BlankConsole/x64/Debug/CST116-B.369d37de.tlog/link.read.1.tlog
new file mode 100644
index 0000000..c2e2d4d
--- /dev/null
+++ b/CST116-BlankConsole/x64/Debug/CST116-B.369d37de.tlog/link.read.1.tlog
Binary files differ
diff --git a/CST116-BlankConsole/x64/Debug/CST116-B.369d37de.tlog/link.write.1.tlog b/CST116-BlankConsole/x64/Debug/CST116-B.369d37de.tlog/link.write.1.tlog
new file mode 100644
index 0000000..7445272
--- /dev/null
+++ b/CST116-BlankConsole/x64/Debug/CST116-B.369d37de.tlog/link.write.1.tlog
Binary files differ
diff --git a/CST116-BlankConsole/x64/Debug/CST116-BlankConsole.exe b/CST116-BlankConsole/x64/Debug/CST116-BlankConsole.exe
new file mode 100644
index 0000000..8c9bf3b
--- /dev/null
+++ b/CST116-BlankConsole/x64/Debug/CST116-BlankConsole.exe
Binary files differ
diff --git a/CST116-BlankConsole/x64/Debug/CST116-BlankConsole.exe.recipe b/CST116-BlankConsole/x64/Debug/CST116-BlankConsole.exe.recipe
new file mode 100644
index 0000000..5c94228
--- /dev/null
+++ b/CST116-BlankConsole/x64/Debug/CST116-BlankConsole.exe.recipe
@@ -0,0 +1,11 @@
+<?xml version="1.0" encoding="utf-8"?>
+<Project>
+ <ProjectOutputs>
+ <ProjectOutput>
+ <FullPath>C:\Users\cowpi\Source\Repos\cst116-lab0-Smith-Benjamin\CST116-BlankConsole\x64\Debug\CST116-BlankConsole.exe</FullPath>
+ </ProjectOutput>
+ </ProjectOutputs>
+ <ContentFiles />
+ <SatelliteDlls />
+ <NonRecipeFileRefs />
+</Project> \ No newline at end of file
diff --git a/CST116-BlankConsole/x64/Debug/CST116-BlankConsole.ilk b/CST116-BlankConsole/x64/Debug/CST116-BlankConsole.ilk
new file mode 100644
index 0000000..fc0f35f
--- /dev/null
+++ b/CST116-BlankConsole/x64/Debug/CST116-BlankConsole.ilk
Binary files differ
diff --git a/CST116-BlankConsole/x64/Debug/CST116-BlankConsole.log b/CST116-BlankConsole/x64/Debug/CST116-BlankConsole.log
new file mode 100644
index 0000000..9b16b15
--- /dev/null
+++ b/CST116-BlankConsole/x64/Debug/CST116-BlankConsole.log
@@ -0,0 +1,2 @@
+ CST116-Lab0-Smith.cpp
+ CST116-BlankConsole.vcxproj -> C:\Users\cowpi\Source\Repos\cst116-lab0-Smith-Benjamin\CST116-BlankConsole\x64\Debug\CST116-BlankConsole.exe
diff --git a/CST116-BlankConsole/x64/Debug/CST116-BlankConsole.pdb b/CST116-BlankConsole/x64/Debug/CST116-BlankConsole.pdb
new file mode 100644
index 0000000..31350dc
--- /dev/null
+++ b/CST116-BlankConsole/x64/Debug/CST116-BlankConsole.pdb
Binary files differ
diff --git a/CST116-BlankConsole/x64/Debug/CST116-BlankConsole.vcxproj.FileListAbsolute.txt b/CST116-BlankConsole/x64/Debug/CST116-BlankConsole.vcxproj.FileListAbsolute.txt
new file mode 100644
index 0000000..a06ad73
--- /dev/null
+++ b/CST116-BlankConsole/x64/Debug/CST116-BlankConsole.vcxproj.FileListAbsolute.txt
@@ -0,0 +1 @@
+C:\Users\cowpi\source\repos\cst116-lab0-Smith-Benjamin\CST116-BlankConsole\x64\Debug\CST116-BlankConsole.exe
diff --git a/CST116-BlankConsole/x64/Debug/CST116-Lab0-Smith.obj b/CST116-BlankConsole/x64/Debug/CST116-Lab0-Smith.obj
new file mode 100644
index 0000000..5f88967
--- /dev/null
+++ b/CST116-BlankConsole/x64/Debug/CST116-Lab0-Smith.obj
Binary files differ
diff --git a/CST116-BlankConsole/x64/Debug/vc143.idb b/CST116-BlankConsole/x64/Debug/vc143.idb
new file mode 100644
index 0000000..45f02fb
--- /dev/null
+++ b/CST116-BlankConsole/x64/Debug/vc143.idb
Binary files differ
diff --git a/CST116-BlankConsole/x64/Debug/vc143.pdb b/CST116-BlankConsole/x64/Debug/vc143.pdb
new file mode 100644
index 0000000..be21f07
--- /dev/null
+++ b/CST116-BlankConsole/x64/Debug/vc143.pdb
Binary files differ
diff --git a/CST116-BlankConsole/CST116-BlankConsole.cpp b/CST116-BlankConsole/CST116-Lab0-Smith.cpp
index f52b208..1c4d50f 100644
--- a/CST116-BlankConsole/CST116-BlankConsole.cpp
+++ b/CST116-BlankConsole/CST116-Lab0-Smith.cpp
@@ -1,20 +1,27 @@
-// CST116-BlankConsole.cpp : This file contains the 'main' function. Program execution begins and ends there.
-//
-
-#include <iostream>
-
-int main()
-{
- std::cout << "Hello World!\n";
-}
-
-// Run program: Ctrl + F5 or Debug > Start Without Debugging menu
-// Debug program: F5 or Debug > Start Debugging menu
-
-// Tips for Getting Started:
-// 1. Use the Solution Explorer window to add/manage files
-// 2. Use the Team Explorer window to connect to source control
-// 3. Use the Output window to see build output and other messages
-// 4. Use the Error List window to view errors
-// 5. Go to Project > Add New Item to create new code files, or Project > Add Existing Item to add existing code files to the project
-// 6. In the future, to open this project again, go to File > Open > Project and select the .sln file
+// CST116-BlankConsole.cpp : This file contains the 'main' function. Program execution begins and ends there.
+//Benjamin Smith
+//CST116
+//Lab #0
+//IDE, Simple Program, GitHub
+
+#include <iostream>
+
+using std::cout;
+using std::endl;
+
+int main()
+{
+ cout << "Hello World!" << endl;
+ cout << "My name is Benjamin Smith. My Github it Smith-Benjamin" << endl;
+}
+
+// Run program: Ctrl + F5 or Debug > Start Without Debugging menu
+// Debug program: F5 or Debug > Start Debugging menu
+
+// Tips for Getting Started:
+// 1. Use the Solution Explorer window to add/manage files
+// 2. Use the Team Explorer window to connect to source control
+// 3. Use the Output window to see build output and other messages
+// 4. Use the Error List window to view errors
+// 5. Go to Project > Add New Item to create new code files, or Project > Add Existing Item to add existing code files to the project
+// 6. In the future, to open this project again, go to File > Open > Project and select the .sln file